import setuptools
setuptools.setup(
        name= 'AlasbahiCul',
        version='0.1',
        author='Fuad Alasbahi',
        description='Sample fuad lib in python',
        packages=setuptools.find_packages(),
        calssifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: MIT License"
        ]
        )